---
sidebar_label: time_statistics
title: modules.statistics.time_statistics
---

## TimeStatistics Objects

```python
class TimeStatistics(Experiment)
```

Compute the evolution of a model through time. Depends on
Event Filters, Statistics and Custom Statistics modules.

